var Uri = android.net.Uri;
import { Telemetry } from './util/telemetry';
export class Auth0 {
    constructor(clientId, domain, configurationDomain) {
        this.clientId = clientId;
        this.domainUrl = this.ensureValidUrl(domain);
        if (this.domainUrl == null) {
            throw new java.lang.IllegalArgumentException(`Invalid domain url: '${domain}'`);
        }
        this.configurationUrl = this.resolveConfiguration(configurationDomain, this.domainUrl);
        this.telemetry = new Telemetry('Auth0.NativeScript', '0.0.0');
    }
    getClientId() {
        return this.clientId;
    }
    getDomainUrl() {
        return this.domainUrl.toString();
    }
    getConfigurationUrl() {
        return this.configurationUrl.toString();
    }
    getAuthorizeUrl() {
        return this.domainUrl.buildUpon()
            .appendEncodedPath("authorize")
            .build()
            .toString();
    }
    getTelemetry() {
        return this.telemetry;
    }
    setTelemetry(telemetry) {
        this.telemetry = telemetry;
    }
    doNotSendTelemetry() {
        this.telemetry = null;
    }
    isLoggingEnabled() {
        return this.loggingEnabled;
    }
    setLoggingEnabled(enabled) {
        this.loggingEnabled = enabled;
    }
    isTLS12Enforced() {
        return this.tls12Enforced;
    }
    setTLS12Enforced(enforced) {
        this.tls12Enforced = enforced;
    }
    resolveConfiguration(configurationDomain, domainUrl) {
        let url = this.ensureValidUrl(configurationDomain);
        if (url == null) {
            const host = domainUrl.getHost();
            if (host.endsWith(Auth0.DOT_AUTH0_DOT_COM)) {
                const parts = host.split('.');
                if (parts.length > 3) {
                    url = Uri.parse(`https://cdn.${parts[parts.length - 3]}${Auth0.DOT_AUTH0_DOT_COM}`);
                }
                else {
                    url = Uri.parse(Auth0.AUTH0_US_CDN_URL);
                }
            }
            else {
                url = domainUrl;
            }
        }
        return url;
    }
    ensureValidUrl(url) {
        if (url == null) {
            return null;
        }
        const safeUrl = url.startsWith("http") ? url : "https://" + url;
        return Uri.parse(safeUrl);
    }
    static getResourceFromContext(context, resName) {
        const stringRes = context.getResources().getIdentifier(resName, "string", context.getPackageName());
        if (stringRes === 0) {
            throw new java.lang.IllegalArgumentException(`The 'R.string.${resName}' value it's not defined in your project's resources file.`);
        }
        return context.getString(stringRes);
    }
}
Auth0.AUTH0_US_CDN_URL = "https://cdn.auth0.com";
Auth0.DOT_AUTH0_DOT_COM = ".auth0.com";
//# sourceMappingURL=auth0.js.map