export class ParameterBuilder {
    constructor(parameters) {
        if (parameters == null) {
            throw new java.lang.IllegalArgumentException("Must provide non-null parameters");
        }
        this.parameters = Object.assign({}, parameters);
    }
    setClientId(clientId) {
        return this.setParameter(ParameterBuilder.CLIENT_ID_KEY, clientId);
    }
    setGrantType(grantType) {
        return this.setParameter(ParameterBuilder.GRANT_TYPE_KEY, grantType);
    }
    setConnection(connection) {
        return this.setParameter(ParameterBuilder.CONNECTION_KEY, connection);
    }
    setRealm(realm) {
        return this.setParameter(ParameterBuilder.REALM_KEY, realm);
    }
    setScope(scope) {
        return this.setParameter(ParameterBuilder.SCOPE_KEY, scope);
    }
    setAudience(audience) {
        return this.setParameter(ParameterBuilder.AUDIENCE_KEY, audience);
    }
    setAccessToken(accessToken) {
        return this.setParameter(ParameterBuilder.ACCESS_TOKEN_KEY, accessToken);
    }
    setRefreshToken(refreshToken) {
        return this.setParameter(ParameterBuilder.REFRESH_TOKEN_KEY, refreshToken);
    }
    setParameter(key, value) {
        if (value == null) {
            delete this.parameters[key];
        }
        else {
            this.parameters[key] = value;
        }
        return this;
    }
    addAll(parameters) {
        if (parameters != null) {
            for (const k in parameters) {
                if (parameters[k] != null) {
                    this.parameters[k] = parameters[k];
                }
            }
        }
        return this;
    }
    clearAll() {
        this.parameters.clear();
        return this;
    }
    asDictionary() {
        return Object.assign({}, this.parameters);
    }
    static newAuthenticationBuilder() {
        return ParameterBuilder
            .newBuilder()
            .setScope(ParameterBuilder.SCOPE_OPENID);
    }
    static newBuilder(parameters) {
        return new ParameterBuilder(parameters || {});
    }
}
ParameterBuilder.GRANT_TYPE_REFRESH_TOKEN = "refresh_token";
ParameterBuilder.GRANT_TYPE_PASSWORD = "password";
ParameterBuilder.GRANT_TYPE_PASSWORD_REALM = "http://auth0.com/oauth/grant-type/password-realm";
ParameterBuilder.GRANT_TYPE_AUTHORIZATION_CODE = "authorization_code";
ParameterBuilder.GRANT_TYPE_MFA_OTP = "http://auth0.com/oauth/grant-type/mfa-otp";
ParameterBuilder.SCOPE_OPENID = "openid";
ParameterBuilder.SCOPE_OFFLINE_ACCESS = "openid offline_access";
ParameterBuilder.ID_TOKEN_KEY = "id_token";
ParameterBuilder.SCOPE_KEY = "scope";
ParameterBuilder.REFRESH_TOKEN_KEY = "refresh_token";
ParameterBuilder.CONNECTION_KEY = "connection";
ParameterBuilder.REALM_KEY = "realm";
ParameterBuilder.ACCESS_TOKEN_KEY = "access_token";
ParameterBuilder.CLIENT_ID_KEY = "client_id";
ParameterBuilder.GRANT_TYPE_KEY = "grant_type";
ParameterBuilder.AUDIENCE_KEY = "audience";
//# sourceMappingURL=parameterBuilder.js.map