var Log = android.util.Log;
import { AlgorithmHelper } from './algorithmHelper';
export class PKCE {
    constructor(apiClient, redirectUri, algorithmHelper = new AlgorithmHelper()) {
        this.apiClient = apiClient;
        this.redirectUri = redirectUri;
        this.codeVerifier = algorithmHelper.generateCodeVerifier();
        this.codeChallenge = algorithmHelper.generateCodeChallenge(this.codeVerifier);
    }
    getCodeChallenge() {
        return this.codeChallenge;
    }
    getToken(authorizationCode, callback) {
        this.apiClient.token(authorizationCode, this.redirectUri)
            .setCodeVerifier(this.codeVerifier)
            .start({
            onSuccess: function (payload) {
                callback.onSuccess(payload);
            },
            onFailure: function (error) {
                if ("Unauthorized" === error.getDescription()) {
                    Log.e(PKCE.TAG, `Please go to 'https://manage.auth0.com/#/applications/${this.apiClient.getClientId()}/settings' and set 'Client Type' to 'Native' to enable PKCE.`);
                }
                callback.onFailure(error);
            }
        });
    }
    static isAvailable(algorithmHelper = new AlgorithmHelper()) {
        try {
            const input = algorithmHelper.getASCIIBytes("test");
            algorithmHelper.getSHA256(input);
        }
        catch (ignored) {
            return false;
        }
        return true;
    }
}
PKCE.TAG = 'PKCE';
//# sourceMappingURL=pkce.js.map