import { Auth0Error } from './auth0Error';
export class AuthenticationError extends Auth0Error {
    constructor(infoOrString = undefined, statusCode = 0) {
        if (typeof infoOrString === 'object') {
            infoOrString['description'] = infoOrString['description'] || infoOrString['error_description'];
        }
        super(infoOrString, statusCode);
        Object.setPrototypeOf(this, new.target.prototype);
    }
    get isMultifactorRequired() {
        return this.code === "a0.mfa_required" || this.code === "mfa_required";
    }
    get isMultifactorEnrollRequired() {
        return this.code === "a0.mfa_registration_required" || this.code === "unsupported_challenge_type";
    }
    get isMultifactorCodeInvalid() {
        return this.code === "a0.mfa_invalid_code" || this.code === "invalid_grant" && this.message === "Invalid otp_code.";
    }
    get isMultifactorTokenInvalid() {
        return this.code === "expired_token" && this.message === "mfa_token is expired" || this.code === "invalid_grant" && this.message === "Malformed mfa_token";
    }
    get isPasswordNotStrongEnough() {
        return this.code === "invalid_password" && this.value("name") === "PasswordStrengthError";
    }
    get isPasswordAlreadyUsed() {
        return this.code === "invalid_password" && this.value("name") === "PasswordHistoryError";
    }
    get isRuleError() {
        return this.code === "unauthorized";
    }
    get isInvalidCredentials() {
        return this.code === "invalid_user_password" || (this.code === "invalid_grant" && this.message === "Wrong email or password.");
    }
    get isAccessDenied() {
        return this.code === "access_denied";
    }
    get isTooManyAttempts() {
        return this.code === "too_many_attempts";
    }
    value(key) { return this.info[key]; }
}
//# sourceMappingURL=authenticationError.js.map